var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { configurationService } from './index';
describe('configuration.service', () => {
    it('match exception [无法匹配到host]', () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            configurationService.injectConfigurations([
                {
                    whiteHosts: ['localhost:3000'],
                    publicUrl: { baseUrl: '' }
                }
            ]);
        }
        catch (e) {
            expect(e.message).toBe(`[configurations whiteHosts] host: localhost cannot match configuration`);
        }
    }));
    it('match exception [whiteHosts 类型错误]', () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            configurationService.injectConfigurations([
                {
                    whiteHosts: {},
                    publicUrl: { baseUrl: '' }
                }
            ]);
        }
        catch (e) {
            expect(e.message).toBe(`[configurations whiteHosts] should be array, but got object`);
        }
    }));
    it('match exception [publicUrl 类型错误]', () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            configurationService.injectConfigurations([
                {
                    whiteHosts: ['localhost:3000'],
                    publicUrl: ''
                }
            ]);
        }
        catch (e) {
            expect(e.message).toBe('[configurations publicUrl] should be object, but got string');
        }
    }));
    it('match exception [publicUrl key不一致]', () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            configurationService.injectConfigurations([
                {
                    whiteHosts: ['localhost:3000'],
                    publicUrl: { url: '' }
                },
                {
                    whiteHosts: ['localhost:3000'],
                    publicUrl: {
                        url2: ''
                    }
                }
            ]);
        }
        catch (e) {
            expect(e.message).toBe('配置中的publicUrl key不一致，请保持一致，否则可能导致某个环境下出现异常');
        }
    }));
    it('match exception [injectConfigurations 参数错误]', () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            configurationService.injectConfigurations(undefined);
        }
        catch (e) {
            expect(e.message).toBe('[configurations whiteHosts] host: localhost cannot match configuration');
        }
    }));
    it('match exception [whiteHosts 匹配多个]', () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            configurationService.injectConfigurations([
                {
                    whiteHosts: ['localhost'],
                    publicUrl: { baseUrl: '' }
                },
                {
                    whiteHosts: ['localhost'],
                    publicUrl: { baseUrl: '' }
                }
            ]);
        }
        catch (e) {
            expect(e).toBe('Warning: [configurations whiteHosts] host 匹配到了多个config，将使用第一个config');
        }
    }));
    it('match exception [router 类型错误]', () => __awaiter(void 0, void 0, void 0, function* () {
        const defualt = {
            whiteHosts: ['localhost'],
            publicUrl: { baseUrl: '' },
            router: ''
        };
        const config = configurationService.injectConfigurations([defualt]);
        expect(config).toEqual(Object.assign({ NODE_ENV: 'test', history: config.history }, defualt));
    }));
    it('match normal', () => __awaiter(void 0, void 0, void 0, function* () {
        const defualt = {
            whiteHosts: ['localhost'],
            publicUrl: { baseUrl: '' },
            router: {
                baseName: '/'
            }
        };
        const config = configurationService.injectConfigurations([defualt]);
        expect(config).toEqual(Object.assign({ NODE_ENV: 'test', history: config.history }, defualt));
        const getConfigResult = configurationService.getConfiguration();
        expect(getConfigResult).toEqual(Object.assign({ NODE_ENV: 'test', history: getConfigResult.history }, defualt));
    }));
});
//# sourceMappingURL=configuration.service.test.js.map